@@ -20,6 +20,7 @@ from gcp_airflow_foundations.operators.gcp.schema_parsing.schema_parsing_operato
 from gcp_airflow_foundations.source_class.schema_source_config import SchemaSourceConfig
 from gcp_airflow_foundations.operators.gcp.create_dataset import CustomBigQueryCreateEmptyDatasetOperator
 
+
 def load_builder(
     data_source: SourceConfig,
     table_config: SourceTableConfig,
@@ -53,11 +54,15 @@ def load_builder(
     ods_suffix = data_source.ods_suffix
     hds_suffix = data_source.hds_suffix
 
-    ods_table_config.table_id = f"{landing_zone_table_name_override}{ods_suffix}"
+    dag_table_id = table_config.table_name
+    ods_table_id = f"{landing_zone_table_name_override}{ods_suffix}"
+    hds_table_id = f"{landing_zone_table_name_override}{hds_suffix}"
 
     parse_schema = ParseSchema(
         task_id="schema_parsing",
         schema_config=schema_config,
+        ods_table_id=ods_table_id,
+        hds_table_id=hds_table_id,
         column_mapping=column_mapping,
         column_casting=column_casting,
         new_column_udfs=new_column_udfs,
@@ -68,7 +73,8 @@ def load_builder(
 
     ods_task_group = ods_builder(
         project_id=project_id,
-        table_id=ods_table_config.table_id,
+        table_id=ods_table_id,
+        dag_table_id=dag_table_id,
         dataset_id=dataset_id,
         landing_zone_dataset=landing_zone_dataset,
         landing_zone_table_name_override=landing_zone_table_name_override,
@@ -90,10 +96,11 @@ def load_builder(
 
         hds_task_group = hds_builder(
             project_id=project_id,
-            table_id=hds_table_config.table_id,
+            table_id=hds_table_id,
+            dag_table_id=dag_table_id,
             dataset_id=dataset_hds_id,
             landing_zone_dataset=dataset_id,
-            landing_zone_table_name_override=ods_table_config.table_id,
+            landing_zone_table_name_override=ods_table_id,
             surrogate_keys=surrogate_keys,
             column_mapping=column_mapping,
             column_casting=column_casting,
@@ -136,7 +143,7 @@ def load_builder(
             {
                 "datastore": "ods",
                 "project_id": project_id,
-                "table_id": ods_table_config.table_id,
+                "table_id": ods_table_id,
                 "dataset_id": dataset_id,
             }
         ]
@@ -145,7 +152,7 @@ def load_builder(
                 {
                     "datastore": "hds",
                     "project_id": project_id,
-                    "table_id": hds_table_config.table_id,
+                    "table_id": hds_table_id,
                     "dataset_id": dataset_hds_id,
                 }
             )
