@@ -6,7 +6,7 @@ class Level(Enum):
     AD = "ad"
     ADSET = "adset"
     CAMPAIGN = "campaign"
-    ACCOUNT = 'account'
+    ACCOUNT = "account"
 
 
 @unique
@@ -28,4 +28,4 @@ class AccountLookupScope(Enum):
 class ApiObject(Enum):
     INSIGHTS = "INSIGHTS"
     CAMPAIGNS = "CAMPAIGNS"
-    ADSETS = "ADSETS"
\ No newline at end of file
+    ADSETS = "ADSETS"
