@@ -1,33 +1,19 @@
-from typing import Optional
-
-from airflow.models import BaseOperator, BaseOperatorLink
-from airflow.contrib.operators.bigquery_operator import (
-    BigQueryOperator,
-    BigQueryCreateEmptyTableOperator,
-)
-
-from airflow.utils.decorators import apply_defaults
-from airflow.contrib.hooks.bigquery_hook import BigQueryHook
-
-from airflow.exceptions import AirflowException
+from airflow.models import BaseOperator
 
 import logging
 
-from gcp_airflow_foundations.common.gcp.source_schema.gcs import read_schema_from_gcs
 from gcp_airflow_foundations.common.gcp.ods.schema_utils import parse_ods_schema
 from gcp_airflow_foundations.common.gcp.hds.schema_utils import parse_hds_schema
 
 
-from gcp_airflow_foundations.base_class.ods_table_config import OdsTableConfig
-from gcp_airflow_foundations.base_class.hds_table_config import HdsTableConfig
-
-
 class ParseSchema(BaseOperator):
-    @apply_defaults
+    # @apply_defaults
     def __init__(
         self,
         *,
         schema_config,
+        ods_table_id: str,
+        hds_table_id: str = "",
         column_mapping=None,
         column_casting=None,
         new_column_udfs=None,
@@ -43,7 +29,8 @@ class ParseSchema(BaseOperator):
         self.new_column_udfs = new_column_udfs
         self.data_source = data_source
         self.table_config = table_config
-
+        self.ods_table_id = ods_table_id,
+        self.hds_table_id = hds_table_id,
         self.ods_table_config = table_config.ods_config
         self.hds_table_config = table_config.hds_config
 
@@ -81,7 +68,7 @@ class ParseSchema(BaseOperator):
 
         if self.ods_table_config:
             schema_xcom[
-                f"{self.data_source.dataset_data_name}.{self.ods_table_config.table_id}"
+                f"{self.data_source.dataset_data_name}.{self.ods_table_id[0]}"
             ] = parse_ods_schema(
                 schema_fields=source_schema_fields,
                 ods_metadata=self.ods_table_config.ods_metadata,
@@ -89,7 +76,7 @@ class ParseSchema(BaseOperator):
 
         if self.hds_table_config:
             schema_xcom[
-                f"{self.data_source.dataset_hds_override}.{self.hds_table_config.table_id}"
+                f"{self.data_source.dataset_hds_override}.{self.hds_table_id[0]}"
             ] = parse_hds_schema(
                 schema_fields=source_schema_fields,
                 hds_metadata=self.hds_table_config.hds_metadata,
