@@ -1,16 +1,24 @@
 from gcp_airflow_foundations.enums.source_type import SourceType
 
 from gcp_airflow_foundations.source_class.twilio_source import TwilioToBQDagBuilder
-from gcp_airflow_foundations.source_class.salesforce_source import SalesforcetoBQDagBuilder
-from gcp_airflow_foundations.source_class.oracle_dataflow_source import OracleToBQDataflowDagBuilder
+from gcp_airflow_foundations.source_class.salesforce_source import (
+    SalesforcetoBQDagBuilder,
+)
+from gcp_airflow_foundations.source_class.oracle_dataflow_source import (
+    OracleToBQDataflowDagBuilder,
+)
 from gcp_airflow_foundations.source_class.facebook import FacebooktoBQDagBuilder
 
-from gcp_airflow_foundations.base_class.data_source_table_config import DataSourceTablesConfig
+from gcp_airflow_foundations.base_class.data_source_table_config import (
+    DataSourceTablesConfig,
+)
 
 import logging
 
 
-def get_dag_builder(source: SourceType, default_task_args: dict, config: DataSourceTablesConfig):
+def get_dag_builder(
+    source: SourceType, default_task_args: dict, config: DataSourceTablesConfig
+):
     logging.info(f"Get DAG builder for {source}")
     if source == SourceType.TWILIO:
         logging.info("Selecting Twilio builder")
@@ -26,4 +34,4 @@ def get_dag_builder(source: SourceType, default_task_args: dict, config: DataSou
         return FacebooktoBQDagBuilder(default_task_args, config)
     else:
         logging.info(f"Invalid source {source}")
-        raise Exception(f"Invalid source {source}")
\ No newline at end of file
+        raise Exception(f"Invalid source {source}")
